@@ -1,5 +1,6 @@
 import unicodedata
 import re
+import math
 
 
 def slugify(value):
@@ -9,25 +10,25 @@ def slugify(value):
     and converts spaces to hyphens.
     """
     value = str(value)
-    value = unicodedata.normalize('NFKD', value).encode('ascii', 'ignore')
-    value = value.decode('utf-8')
-    value = str(re.sub(r'[^\w\s-]', '', value)).strip().lower()
-    return re.sub(r'[-\s]+', '-', value)
+    value = unicodedata.normalize("NFKD", value).encode("ascii", "ignore")
+    value = value.decode("utf-8")
+    value = str(re.sub(r"[^\w\s-]", "", value)).strip().lower()
+    return re.sub(r"[-\s]+", "-", value)
 
 
 def add_url_tags(text):
     """Surround URL with <a> tags."""
     return re.sub(
-        r'(http[s]?://('
-        r'?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+)',
+        r"(http[s]?://("
+        r"?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+)",
         r'<a href="\1">\1</a>',
-        text
+        text,
     )
 
 
 def lookup_string_in_text(string, text):
     """Return full line if string found in the multi-line text."""
-    output_lines = text.split('\n')
+    output_lines = text.split("\n")
     for line in output_lines:
         if string in line:
             return line
@@ -48,13 +49,13 @@ def parse_version(version):
     Returns:
         tuple: (version number as list, prefix, suffix)
     """
-    version_match = re.search(r'(\d[\d\.]+\d)', version)
+    version_match = re.search(r"(\d[\d\.]+\d)", version)
     if not version_match:
-        return [], '', ''
+        return [], "", ""
     version_number = version_match.groups()[0]
     prefix = version[0:version_match.span()[0]]
     suffix = version[version_match.span()[1]:]
-    return [int(p) for p in version_number.split('.')], prefix, suffix
+    return [int(p) for p in version_number.split(".")], prefix, suffix
 
 
 def version_sort(versions, reverse=False):
@@ -65,6 +66,7 @@ def version_sort(versions, reverse=False):
         sort_key.append(prefix)
         sort_key.append(suffix)
         return sort_key
+
     return sorted(versions, key=version_key, reverse=reverse)
 
 
@@ -79,16 +81,53 @@ def unpack_dependencies(string):
     """
     if not string:
         return []
-    dependencies = [dep.strip() for dep in string.split(',') if dep.strip()]
+    dependencies = [dep.strip() for dep in string.split(",") if dep.strip()]
     for index, dependency in enumerate(dependencies):
-        if '|' in dependency:
-            dependencies[index] = tuple([
-                option.strip()
-                for option in dependency.split('|')
-                if option.strip()
-            ])
-    return [
-        dependency
-        for dependency in dependencies
-        if dependency
-    ]
+        if "|" in dependency:
+            dependencies[index] = tuple(
+                [option.strip() for option in dependency.split("|") if option.strip()]
+            )
+    return [dependency for dependency in dependencies if dependency]
+
+
+def gtk_safe(string):
+    """Return a string ready to used in Gtk widgets"""
+    if not string:
+        string = ""
+    return string.replace("&", "&amp;").replace("<", "&lt;").replace(">", "&gt;")
+
+
+def escape_gtk_label(string):
+    """Used to escape some characters for display in Gtk labels"""
+    return re.sub("&(?!amp;)", "&amp;", string)
+
+
+def get_formatted_playtime(playtime):
+    """Return a human readable value of the play time"""
+    if not playtime:
+        return "No play time recorded"
+
+    try:
+        playtime = float(playtime)
+    except TypeError:
+        return "Invalid playtime %s" % playtime
+    hours = math.floor(playtime)
+
+    if hours:
+        hours_text = "%d hour%s" % (hours, "s" if hours > 1 else "")
+    else:
+        hours_text = ""
+
+    minutes = int((playtime - hours) * 60)
+    if minutes:
+        minutes_text = "%d minute%s" % (minutes, "s" if minutes > 1 else "")
+    else:
+        minutes_text = ""
+
+    formatted_time = " and ".join([text for text in (hours_text, minutes_text) if text])
+    if formatted_time:
+        return formatted_time
+    seconds = int(hours * 3600)
+    if seconds:
+        return "%d seconds" % seconds
+    return "No play time recorded"
